@@ -95,7 +95,8 @@ class DatazillaPerfPoster(object):
         version = mozversion.get_version(sources=sources, dm_type='adb')
         self.ancillary_data['build_revision'] = version.get('build_changeset')
         self.ancillary_data['gaia_revision'] = version.get('gaia_changeset')
-        self.ancillary_data['gecko_revision'] = version.get('gecko_changeset')
+        self.ancillary_data['gecko_repository'] = version.get('application_repository')
+        self.ancillary_data['gecko_revision'] = version.get('application_changeset')
         self.ancillary_data['ro.build.version.incremental'] = version.get(
             'device_firmware_version_incremental')
         self.ancillary_data['ro.build.version.release'] = version.get(
@@ -106,6 +107,7 @@ class DatazillaPerfPoster(object):
         self.required = {
             'generated by': self.ancillary_data.get('generated_by'),
             'gaia revision': self.ancillary_data.get('gaia_revision'),
+            'gecko repository': self.ancillary_data.get('gecko_repository'),
             'gecko revision': self.ancillary_data.get('gecko_revision'),
             'build revision': self.ancillary_data.get('build_revision'),
             'protocol': datazilla_config['protocol'],
@@ -672,10 +674,9 @@ class B2GPerfScrollMessagesTest(B2GPerfScrollTest):
     def before_scroll(self):
         B2GPerfScrollTest.before_scroll(self)
         self.logger.debug('Waiting for messages to be displayed')
-        Wait(self.marionette, timeout=240).until(
-            expected.element_displayed(
-                self.marionette.find_element(
-                    By.CSS_SELECTOR, '#threads-container li')))
+        Wait(self.marionette).until(expected.element_displayed(
+            Wait(self.marionette, timeout=240).until(expected.element_present(
+                By.CSS_SELECTOR, '#threads-container li'))))
 
     def populate_databases(self):
         self.b2gpopulate.populate_messages(200, restart=False)
